# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

import types

__config__ = pulumi.Config('docker')


class _ExportableConfig(types.ModuleType):
    @property
    def ca_material(self) -> Optional[str]:
        """
        PEM-encoded content of Docker host CA certificate
        """
        return __config__.get('caMaterial')

    @property
    def cert_material(self) -> Optional[str]:
        """
        PEM-encoded content of Docker client certificate
        """
        return __config__.get('certMaterial')

    @property
    def cert_path(self) -> Optional[str]:
        """
        Path to directory with Docker TLS config
        """
        return __config__.get('certPath')

    @property
    def host(self) -> Optional[str]:
        """
        The Docker daemon address
        """
        return __config__.get('host') or _utilities.get_env('DOCKER_HOST')

    @property
    def key_material(self) -> Optional[str]:
        """
        PEM-encoded content of Docker client private key
        """
        return __config__.get('keyMaterial')

    @property
    def registry_auth(self) -> Optional[str]:
        return __config__.get('registryAuth')

    @property
    def ssh_opts(self) -> Optional[str]:
        """
        Additional SSH option flags to be appended when using `ssh://` protocol
        """
        return __config__.get('sshOpts')

